@@ -21,7 +21,7 @@ function(
 	parallel.config=NULL) {
 
 	started.at <- proc.time()
-	message(paste("Started combineSGP", date()))
+	messageSGP(paste("Started combineSGP", prettyDate()))
 
 	ID <- CONTENT_AREA <- YEAR <- GRADE <- YEAR_INTEGER_TMP <- ACHIEVEMENT_LEVEL <- CATCH_UP_KEEP_UP_STATUS_INITIAL <- MOVE_UP_STAY_UP_STATUS_INITIAL <- VALID_CASE <- NULL
 	MOVE_UP_STAY_UP_STATUS <- CATCH_UP_KEEP_UP_STATUS <- ACHIEVEMENT_LEVEL_PRIOR <- target.type <- SGP_PROJECTION_GROUP <- NULL
@@ -53,9 +53,9 @@ function(
 
 	### Create SGP_TARGET_CONTENT_AREA in certain cases
 
-	if (is.null(sgp.target.content_areas) & any(sapply(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]], function(x) length(unique(x))) > 1)) {
+	if (is.null(sgp.target.content_areas) & any(sapply(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]], function(x) uniqueN(x)) > 1)) {
 		sgp.target.content_areas <- TRUE
-		tmp.messages <- c(tmp.messages, "\tNOTE: Multple content areas detected for student growth targets. 'sgp.target.content_areas set to TRUE.\n")
+		tmp.messages <- c(tmp.messages, "\tNOTE: Multiple content areas detected for student growth targets. 'sgp.target.content_areas set to TRUE.\n")
 	}
 
 	### Check to see if max.sgp.target.years.forward if configured in SGPstateData
@@ -73,18 +73,18 @@ function(
 
 	### Setup for equated SGPs and scale score targets
 
-	if (!is.null(SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][["Year"]])) {
-		year.for.equate <- tail(sort(unique(sgp_object@Data$YEAR)), 1)
-		if (SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][["Year"]]!=year.for.equate) {
+	if (!is.null(year.for.equate <- SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][["Year"]])) {
+		tmp.last.year <- tail(sort(unique(sgp_object@Data, by='YEAR')[['YEAR']]), 1)
+		if (year.for.equate!=tmp.last.year) {
 			sgp.percentiles.equated <- FALSE
 			if (sgp.target.scale.scores) sgp.projections.equated <- NULL
 		} else {
 			sgp.percentiles.equated <- TRUE
-			if (sgp.target.scale.scores) sgp.projections.equated <- list(Year=year.for.equate, Linkages=sgp_object@SGP[['Linkages']])
+			if (sgp.target.scale.scores) sgp.projections.equated <- list(Year=tmp.last.year, Linkages=sgp_object@SGP[['Linkages']])
 		}
 	} else {
 		if (sgp.percentiles.equated) {
-			message("\tNOTE: 'sgp.percentiles.equated' has been set to TRUE but no meta-data exists in SGPstateData associated with the assessment transition. Equated/linked SGP analyses require meta-data embedded in 'SGPstateData' to correctly work. Contact package administrators on how such data can be added to the package.")
+			messageSGP("\tNOTE: 'sgp.percentiles.equated' has been set to TRUE but no meta-data exists in SGPstateData associated with the assessment transition. Equated/linked SGP analyses require meta-data embedded in 'SGPstateData' to correctly work. Contact package administrators on how such data can be added to the package.")
 			sgp.percentiles.equated <- FALSE
 			sgp.target.scale.scores <- FALSE
 		}
@@ -94,7 +94,7 @@ function(
 
 	### Utility functions
 
-	get.target.arguments <- function(system.type, target.type=NULL, projection.unit.label) {
+	get.target.arguments <- function(system.type, target.type=NULL, projection.unit.label, year.for.equate) {
 		tmp.list <- list()
 		if (is.null(system.type)) {
 			if (identical(target.type, c("sgp.projections", "sgp.projections.lagged"))) system.type <- "Cohort Referenced"
@@ -112,7 +112,13 @@ function(
 
 		if (identical(system.type, "Cohort Referenced")) {
 			tmp.list[['target.type']] <- intersect(target.type, c("sgp.projections", "sgp.projections.lagged"))
-			tmp.list[['my.sgp']] <- "SGP"
+			if (!is.null(year.for.equate) && !sgp.percentiles.equated) {
+				tmp.variable.name <- paste("SGP_FROM", year.for.equate, sep="_")
+				tmp.messages <- c(tmp.messages, paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will be compared to ", tmp.variable.name, ".\n"))
+				tmp.list[['my.sgp']] <- tmp.variable.name
+			} else {
+				tmp.list[['my.sgp']] <- "SGP"
+			}
 			tmp.list[['my.sgp.target']] <- paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, sep="_")
 			tmp.list[['my.sgp.target.content_area']] <- paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, "CONTENT_AREA", sep="_")
 			tmp.list[['my.sgp.target.move.up.stay.up']] <- paste("SGP_TARGET_MOVE_UP_STAY_UP", max.sgp.target.years.forward, projection.unit.label, sep="_")
@@ -128,7 +134,13 @@ function(
 		}
 		if (identical(system.type, "Cohort and Baseline Referenced")) {
 			tmp.list[['target.type']] <- intersect(target.type, c("sgp.projections", "sgp.projections.baseline", "sgp.projections.lagged", "sgp.projections.lagged.baseline"))
-			tmp.list[['my.sgp']] <- c("SGP", "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
+			if (!is.null(year.for.equate) && !sgp.percentiles.equated) {
+				tmp.year.diff <- as.numeric(unlist(strsplit(tail(sort(unique(sgp_object@Data, by='YEAR')[['YEAR']]), 1), "_"))[1]) - as.numeric(unlist(strsplit(year.for.equate, "_"))[1])
+				tmp.messages <- c(tmp.messages, paste0("\tNOTE: Due to test transition in ", year.for.equate, " SGP_TARGET will utilize ", paste("SGP_MAX_ORDER", tmp.year.diff, sep="_"), ".\n"))
+				tmp.list[['my.sgp']] <- c(paste("SGP_MAX_ORDER", tmp.year.diff, sep="_"), "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
+			} else {
+				tmp.list[['my.sgp']] <- c("SGP", "SGP_BASELINE")[c(sgp.percentiles, sgp.percentiles.baseline)]
+			}
 			tmp.list[['my.sgp.target']] <- c(paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, sep="_"),
 				paste("SGP_TARGET_BASELINE", max.sgp.target.years.forward, projection.unit.label, sep="_"))
 			tmp.list[['my.sgp.target.content_area']] <- c(paste("SGP_TARGET", max.sgp.target.years.forward, projection.unit.label, "CONTENT_AREA", sep="_"),
@@ -145,7 +157,7 @@ function(
 			tmp.list[['target.level']] <- "CATCH_UP_KEEP_UP"
 		}
 		if (!is.null(SGP::SGPstateData[[state]][["SGP_Configuration"]][['sgp.target.types']]) &&
-			length(grep("MUSU", SGP::SGPstateData[[state]][["SGP_Configuration"]][['sgp.target.types']]))==0) {
+			!grepl("MUSU", SGP::SGPstateData[[state]][["SGP_Configuration"]][['sgp.target.types']])) {
 				tmp.list[['target.level']] <- "CATCH_UP_KEEP_UP"
 		}
 
@@ -154,11 +166,10 @@ function(
 
 	catch_keep_move_functions <- c(min, max)
 
-	"%w/o%" <- function(x,y) x[!x %in% y]
-
 	getTargetData <- function(tmp.target.data, projection_group.iter, tmp.target.level.names) {
-		tmp.data <- tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter, c("ID", "CONTENT_AREA", "YEAR", tmp.target.level.names), with=FALSE]
-		return(tmp.data[apply(tmp.data[,tmp.target.level.names, with=FALSE],1,function(x)any(!is.na(x)))])
+		if ("YEAR_WITHIN" %in% names(tmp.target.data)) tmp.var.names <- c("ID", "CONTENT_AREA", "YEAR", "YEAR_WITHIN") else tmp.var.names <- c("ID", "CONTENT_AREA", "YEAR")
+		tmp.data <- tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter, c(tmp.var.names, tmp.target.level.names), with=FALSE]
+		na.omit(tmp.data, cols=grep("MOVE_UP_STAY_UP", tmp.target.level.names, invert=TRUE, value=TRUE))
 	}
 
 
@@ -185,7 +196,7 @@ function(
 			paste("SGP_TARGET_BASELINE_MOVE_UP_STAY_UP", max.sgp.target.years.forward, projection.unit.label, "CURRENT", sep="_"))
 
 		for (tmp.variables.to.null.out in intersect(names(slot.data), variables.to.null.out)) {
-			slot.data[,tmp.variables.to.null.out:=NULL, with=FALSE]
+			slot.data[,(tmp.variables.to.null.out):=NULL]
 		}
 	}
 
@@ -213,13 +224,13 @@ function(
 
 		tmp.data <- data.table(rbindlist(tmp.list, fill=TRUE), VALID_CASE="VALID_CASE", key=key(slot.data))
 
-		if (any(duplicated(tmp.data))) {
+		if (any(duplicated(tmp.data, by=key(tmp.data)))) {
 			tmp.data <- getPreferredSGP(tmp.data, state)
 		}
 
-		variables.to.merge <- names(tmp.data) %w/o% key(slot.data)
+		variables.to.merge <- setdiff(names(tmp.data),  key(slot.data))
 		tmp.index <- slot.data[tmp.data[,key(slot.data), with=FALSE], which=TRUE]
-		slot.data[tmp.index, variables.to.merge := tmp.data[, variables.to.merge, with=FALSE], with=FALSE, nomatch=0]
+		slot.data[tmp.index, (variables.to.merge):=tmp.data[, variables.to.merge, with=FALSE]]
 
 		setkeyv(slot.data, getKey(slot.data))
 	}
@@ -256,13 +267,13 @@ function(
 
 		tmp.data <- data.table(rbindlist(tmp.list, fill=TRUE), VALID_CASE="VALID_CASE", key=key(slot.data))
 
-		if (any(duplicated(tmp.data))) {
+		if (any(duplicated(tmp.data, by=key(tmp.data)))) {
 			tmp.data <- getPreferredSGP(tmp.data, state, type="BASELINE")
 		}
 
-		variables.to.merge <- names(tmp.data) %w/o% key(slot.data)
+		variables.to.merge <- setdiff(names(tmp.data),  key(slot.data))
 		tmp.index <- slot.data[tmp.data[,key(slot.data), with=FALSE], which=TRUE]
-		slot.data[tmp.index, variables.to.merge := tmp.data[, variables.to.merge, with=FALSE], with=FALSE, nomatch=0]
+		slot.data[tmp.index, (variables.to.merge):=tmp.data[, variables.to.merge, with=FALSE]]
 
 		setkeyv(slot.data, getKey(slot.data))
 	}
@@ -296,37 +307,37 @@ function(
 
 	if ((sgp.projections | sgp.projections.baseline | sgp.projections.lagged | sgp.projections.lagged.baseline) & !sgp.target.scale.scores.only) {
 
-		target.args <- get.target.arguments(SGP::SGPstateData[[state]][["Growth"]][["System_Type"]], target.type, projection.unit.label)
+		target.args <- get.target.arguments(SGP::SGPstateData[[state]][["Growth"]][["System_Type"]], target.type, projection.unit.label, year.for.equate)
 
 		for (target.type.iter in target.args[['target.type']]) {
 			for (target.level.iter in target.args[['target.level']]) {
 				tmp.data <- getTargetSGP(sgp_object, content_areas, state, years, target.type.iter, target.level.iter, max.sgp.target.years.forward)
-				if (any(duplicated(tmp.data))) {
+				if (any(duplicated(tmp.data, by=key(tmp.data)))) {
 					duplicated.projections.tf <- TRUE
 					tmp.data <- getPreferredSGP(tmp.data, state, type="TARGET")
 				} else duplicated.projections.tf <- FALSE
-				variables.to.merge <- names(tmp.data) %w/o% key(slot.data)
+				variables.to.merge <- setdiff(names(tmp.data),  key(slot.data))
 				tmp.index <- slot.data[tmp.data[,intersect(key(slot.data), names(tmp.data)), with=FALSE], which=TRUE]
-				slot.data[tmp.index, variables.to.merge := tmp.data[, variables.to.merge, with=FALSE], with=FALSE, nomatch=0]
+				slot.data[tmp.index, (variables.to.merge):=tmp.data[, variables.to.merge, with=FALSE]]
 			}
 		}
 		if (duplicated.projections.tf) {
-			tmp.messages <- c(tmp.messages, paste(
-				"\tNOTE: Multiple Projections exist for individual students. Unique SGP Targets will be created using SGP Progression Preference Table for ", state, ".\n", sep=""))
+			tmp.messages <- c(tmp.messages, paste0(
+				"\tNOTE: Multiple Projections exist for individual students. Unique SGP Targets will be created using SGP Progression Preference Table for ", state, ".\n"))
 		}
 
 		### SGP_TARGET_CONTENT_AREA calculation
 
-		terminal.content_areas <- unique(slot.data[!is.na(target.args[['my.sgp.target']][1])][['CONTENT_AREA']])
+		terminal.content_areas <- unique(na.omit(slot.data, cols=target.args[['my.sgp.target']][1]), by='CONTENT_AREA')[['CONTENT_AREA']]
 		if (!is.null(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]])) {
 			terminal.content_areas <- intersect(terminal.content_areas, sapply(SGP::SGPstateData[[state]][["SGP_Configuration"]][["content_area.projection.sequence"]], tail, 1))
 		}
 
 		if (!is.null(sgp.target.content_areas) && sgp.target.content_areas) {
 			for (my.sgp.target.content_area.iter in target.args[['my.sgp.target.content_area']]) {
-				slot.data[!is.na(get(target.args[['my.sgp.target']][1])), target.args[['my.sgp.target.content_area']] :=
+				slot.data[!is.na(get(target.args[['my.sgp.target']][1])), target.args[['my.sgp.target.content_area']]:=
 					getTargetSGPContentArea(GRADE[1], CONTENT_AREA[1], state, max.sgp.target.years.forward, target.args[['my.sgp.target.content_area.iter']]),
-					by=list(GRADE, CONTENT_AREA), with=FALSE]
+					by=list(GRADE, CONTENT_AREA)]
 			}
 		}
 
@@ -338,34 +349,34 @@ function(
 			slot.data[,CATCH_UP_KEEP_UP_STATUS_INITIAL:=getTargetInitialStatus(ACHIEVEMENT_LEVEL_PRIOR, state, status.type="CATCH_UP_KEEP_UP")]
 
 			for (i in seq_along(target.args[['my.sgp']])) {
-				if (length(grep("BASELINE", target.args[['my.sgp']][i]))==0) my.label <- "CATCH_UP_KEEP_UP_STATUS" else my.label <- "CATCH_UP_KEEP_UP_STATUS_BASELINE"
-				if (my.label %in% names(slot.data)) slot.data[,my.label := NULL, with=FALSE]
-				slot.data[,my.label := rep(as.character(NA), dim(slot.data)[1]), with=FALSE]
+				if (!grepl("BASELINE", target.args[['my.sgp']][i])) my.label <- "CATCH_UP_KEEP_UP_STATUS" else my.label <- "CATCH_UP_KEEP_UP_STATUS_BASELINE"
+				if (my.label %in% names(slot.data)) slot.data[,(my.label):=NULL]
+				slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1])]
 
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Keeping Up" & get(target.args[['my.sgp']][i]) >= get(target.args[['my.sgp.target']][i]),
-					my.label := "Keep Up: Yes", with=FALSE]
+					(my.label):="Keep Up: Yes"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Keeping Up" & get(target.args[['my.sgp']][i]) < get(target.args[['my.sgp.target']][i]),
-					my.label := "Keep Up: No", with=FALSE]
+					(my.label):="Keep Up: No"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Catching Up" & get(target.args[['my.sgp']][i]) >= get(target.args[['my.sgp.target']][i]),
-					my.label := "Catch Up: Yes", with=FALSE]
+					(my.label):="Catch Up: Yes"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Catching Up" & get(target.args[['my.sgp']][i]) < get(target.args[['my.sgp.target']][i]),
-					my.label := "Catch Up: No", with=FALSE]
+					(my.label):="Catch Up: No"]
 
 				### CATCH_UP_KEEP_UP clean up based upon reality
 
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Keeping Up" & get(my.label) == "Keep Up: Yes" &
-					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['NO']], my.label := "Keep Up: No", with=FALSE]
+					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['NO']], (my.label):="Keep Up: No"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Catching Up" & get(my.label) == "Catch Up: No" &
-					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['YES']], my.label := "Catch Up: Yes", with=FALSE]
+					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['YES']], (my.label):="Catch Up: Yes"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Catching Up" & get(my.label) == "Catch Up: Yes" &
 					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['NO']] &
 					GRADE == max(type.convert(GRADE[!is.na(get(target.args[['my.sgp.target']]))], as.is=TRUE)) &
-					CONTENT_AREA %in% terminal.content_areas, my.label := "Catch Up: No", with=FALSE]
+					CONTENT_AREA %in% terminal.content_areas, (my.label):="Catch Up: No"]
 				slot.data[CATCH_UP_KEEP_UP_STATUS_INITIAL == "Keeping Up" & get(my.label) == "Keep Up: No" &
 					ACHIEVEMENT_LEVEL %in% catch.up.keep.up.levels[['YES']] &
 					GRADE == max(type.convert(GRADE[!is.na(get(target.args[['my.sgp.target']]))], as.is=TRUE)) &
-					CONTENT_AREA %in% terminal.content_areas, my.label := "Keep Up: Yes", with=FALSE]
-				slot.data[,my.label := as.factor(get(my.label)), with=FALSE]
+					CONTENT_AREA %in% terminal.content_areas, (my.label):="Keep Up: Yes"]
+				slot.data[,(my.label):=as.factor(get(my.label))]
 			}
 		}
 
@@ -378,39 +389,39 @@ function(
 			slot.data[,MOVE_UP_STAY_UP_STATUS_INITIAL:=getTargetInitialStatus(ACHIEVEMENT_LEVEL_PRIOR, state, status.type="MOVE_UP_STAY_UP")]
 
 			for (i in seq_along(target.args[['my.sgp']])) {
-				if (length(grep("BASELINE", target.args[['my.sgp']][i]))==0) my.label <- "MOVE_UP_STAY_UP_STATUS" else my.label <- "MOVE_UP_STAY_UP_STATUS_BASELINE"
-				if (my.label %in% names(slot.data)) slot.data[,my.label := NULL, with=FALSE]
-				slot.data[,my.label := rep(as.character(NA), dim(slot.data)[1]), with=FALSE]
+				if (!grepl("BASELINE", target.args[['my.sgp']][i])) my.label <- "MOVE_UP_STAY_UP_STATUS" else my.label <- "MOVE_UP_STAY_UP_STATUS_BASELINE"
+				if (my.label %in% names(slot.data)) slot.data[,(my.label):=NULL]
+				slot.data[,(my.label):=rep(as.character(NA), dim(slot.data)[1])]
 
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Staying Up" & get(target.args[['my.sgp']][i]) >= get(target.args[['my.sgp.target.move.up.stay.up']][i]),
-					my.label := "Stay Up: Yes", with=FALSE]
+					(my.label):="Stay Up: Yes"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Staying Up" & get(target.args[['my.sgp']][i]) < get(target.args[['my.sgp.target.move.up.stay.up']][i]),
-					my.label := "Stay Up: No", with=FALSE]
+					(my.label):="Stay Up: No"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Moving Up" & get(target.args[['my.sgp']][i]) >= get(target.args[['my.sgp.target.move.up.stay.up']][i]),
-					my.label := "Move Up: Yes", with=FALSE]
+					(my.label):="Move Up: Yes"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Moving Up" & get(target.args[['my.sgp']][i]) < get(target.args[['my.sgp.target.move.up.stay.up']][i]),
-					my.label := "Move Up: No", with=FALSE]
+					(my.label):="Move Up: No"]
 
 				### MOVE_UP_STAY_UP clean up based upon reality
 
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Staying Up" & get(my.label) == "Stay Up: Yes" &
-					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['NO']], my.label := "Stay Up: No", with=FALSE]
+					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['NO']], (my.label):="Stay Up: No"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Moving Up" & get(my.label) == "Move Up: No" &
-					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['YES']], my.label := "Move Up: Yes", with=FALSE]
+					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['YES']], (my.label):="Move Up: Yes"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Moving Up" & get(my.label) == "Move Up: Yes" &
 					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['NO']] &
 					GRADE == max(type.convert(GRADE[!is.na(get(target.args[['my.sgp.target.move.up.stay.up']]))], as.is=TRUE)) &
-					CONTENT_AREA %in% terminal.content_areas, my.label := "Move Up: No", with=FALSE]
+					CONTENT_AREA %in% terminal.content_areas, (my.label):="Move Up: No"]
 				slot.data[MOVE_UP_STAY_UP_STATUS_INITIAL == "Staying Up" & get(my.label) == "Stay Up: No" &
 					ACHIEVEMENT_LEVEL %in% move.up.stay.up.levels[['YES']] &
 					GRADE == max(type.convert(GRADE[!is.na(get(target.args[['my.sgp.target.move.up.stay.up']]))], as.is=TRUE)) &
-					CONTENT_AREA %in% terminal.content_areas, my.label := "Stay Up: Yes", with=FALSE]
-				slot.data[,my.label := as.factor(get(my.label)), with=FALSE]
+					CONTENT_AREA %in% terminal.content_areas, (my.label):="Stay Up: Yes"]
+				slot.data[,(my.label):=as.factor(get(my.label))]
 			}
 		}
 
 		for (i in intersect(names(slot.data), c("CATCH_UP_KEEP_UP_STATUS_INITIAL", "MOVE_UP_STAY_UP_STATUS_INITIAL"))) {
-			slot.data[,i:=NULL,with=FALSE]
+			slot.data[,(i):=NULL]
 		}
 
 	} ## END sgp.projections.lagged | sgp.projections.lagged.baseline
@@ -422,7 +433,7 @@ function(
 
 	if (sgp.target.scale.scores) {
 
-		if (!exists("target.args")) target.args <- get.target.arguments(SGP::SGPstateData[[state]][["Growth"]][["System_Type"]], target.type, projection.unit.label)
+		if (!exists("target.args")) target.args <- get.target.arguments(SGP::SGPstateData[[state]][["Growth"]][["System_Type"]], target.type, projection.unit.label, year.for.equate)
 		tmp.target.list <- list()
 		for (target.type.iter in target.args[['sgp.target.scale.scores.types']]) {
 			for (target.level.iter in target.args[['target.level']]) {
@@ -434,7 +445,7 @@ function(
 		tmp.target.data <- data.table(Reduce(function(x, y) merge(x, y, all=TRUE), tmp.target.list[!sapply(tmp.target.list, function(x) dim(x)[1]==0)],
 			accumulate=FALSE), key=c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"))
 
-		for (projection_group.iter in unique(tmp.target.data[['SGP_PROJECTION_GROUP']])) {
+		for (projection_group.iter in unique(tmp.target.data, by='SGP_PROJECTION_GROUP')[['SGP_PROJECTION_GROUP']]) {
 			for (target.type.iter in target.args[['sgp.target.scale.scores.types']]) {
 				tmp.target.level.names <-
 					as.character(sapply(target.args[['target.level']], function(x) getTargetName(state, target.type.iter, x, max.sgp.target.years.forward, "SGP_TARGET", projection.unit.label, projection_group.iter)))
@@ -448,10 +459,10 @@ function(
 					getTargetData(tmp.target.data, projection_group.iter, tmp.target.level.names),
 					target.type.iter,
 					tmp.target.level.names,
-					getYearsContentAreasGrades(state, years=unique(tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter][['YEAR']]), content_areas=unique(tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter][['CONTENT_AREA']])),
+					getYearsContentAreasGrades(state, years=unique(tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter], by='YEAR')[['YEAR']], content_areas=unique(tmp.target.data[SGP_PROJECTION_GROUP==projection_group.iter], by='CONTENT_AREA')[['CONTENT_AREA']]),
 					sgp.config=sgp.config,
 					projection_group.identifier=projection_group.iter,
-					sgp.projections.equated=if (length(grep("baseline", target.type.iter) > 0)) NULL else sgp.projections.equated,
+					sgp.projections.equated=if (grepl("baseline", target.type.iter)) NULL else sgp.projections.equated,
 					SGPt=SGPt,
 					parallel.config=parallel.config)
 			}
@@ -464,7 +475,7 @@ function(
 	setkeyv(slot.data, getKey(slot.data))
 	sgp_object@Data <- slot.data
 
-	message(c(tmp.messages, paste("Finished combineSGP", date(), "in", convertTime(timetaken(started.at)), "\n"), sep=""))
+	messageSGP(c(tmp.messages, paste("Finished combineSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n")))
 
 	return(sgp_object)
 } ## END combineSGP Function
