@@ -9,18 +9,27 @@ function(data,
 	VALID_CASE <- ID <- CONTENT_AREA <- YEAR <- ID <- GRADE <- SCALE_SCORE <- DUPLICATED_CASES <- tmp.dups.index.to.remove <- NULL
 	SGPstateData <- SGP::SGPstateData ### Needed due to possible assignment of values to SGPstateData
 
-	## Print start time
+
+	### Print start time
 
 	started.at <- proc.time()
-	messageSGP(paste("\nStarted prepareSGP", date()), "\n")
+	messageSGP(paste("\nStarted prepareSGP", prettyDate()), "\n")
 	messageSGP(match.call())
 
-	## Get state (if possible)
 
-		if (is.null(state)) {
-			tmp.name <- toupper(gsub("_", " ", deparse(substitute(data))))
-			state <- getStateAbbreviation(tmp.name, "prepareSGP")
-		}
+	### Get state (if possible)
+
+	if (is.null(state)) {
+		tmp.name <- toupper(gsub("_", " ", deparse(substitute(data))))
+		state <- getStateAbbreviation(tmp.name, "prepareSGP")
+	}
+
+
+	### Configure arguments
+
+	if (!is.null(SGPstateData[[state]][["SGP_Configuration"]][["fix.duplicates"]])) {
+		fix.duplicates <- SGPstateData[[state]][["SGP_Configuration"]][["fix.duplicates"]]
+	}
 
 
 	### Utility functions
@@ -96,8 +105,8 @@ function(data,
 		## Check see if any of the required variables are missing
 
 		if (!all(required.names %in% variable.names$names.sgp)) {
-			stop(paste("\tNOTE: The {data} object is missing the following column name(s): ", paste(required.names[(required.names %in% variable.names$names.sgp)==FALSE], collapse=", "),
-			". Please identify the variable using the {var.names} argument.", sep=""))
+			stop(paste0("\tNOTE: The {data} object is missing the following column name(s): ", paste(required.names[(required.names %in% variable.names$names.sgp)==FALSE], collapse=", "),
+			". Please identify the variable using the {var.names} argument."))
 		}
 		return(data.frame(variable.names[order(variable.names$column.provided),][,c("names.provided", "names.sgp", "names.type", "names.info", "names.output")], row.names=NULL, stringsAsFactors=FALSE))
 	} ## END getNames
@@ -131,11 +140,11 @@ function(data,
 		## Key data.table and check for duplicate cases
 
 		setkeyv(data@Data, getKey(data))
-		if (is.null(fix.duplicates) && any(duplicated(data@Data["VALID_CASE"]))) {
-			message(paste("\tWARNING: @Data keyed by", paste(getKey(data), collapse=", "), "has duplicate cases. Subsequent joins/merges will likely be corrupt."))
-			message("\tNOTE: Duplicate cases are available in current workspace as 'DUPLICATED_CASES' and saved as 'DUPLICATED_CASES.Rdata'.")
+		if (is.null(fix.duplicates) && any(duplicated(data@Data["VALID_CASE"], by=key(data@Data)))) {
+			messageSGP(paste("\tWARNING: @Data keyed by", paste(getKey(data), collapse=", "), "has duplicate cases. Subsequent joins/merges will likely be corrupt."))
+			messageSGP("\tNOTE: Duplicate cases are available in current workspace as 'DUPLICATED_CASES' and saved as 'DUPLICATED_CASES.Rdata'.")
 			assign("DUPLICATED_CASES",
-				data@Data["VALID_CASE"][unique(data@Data["VALID_CASE"][duplicated(data@Data["VALID_CASE"]), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE])])
+				data@Data["VALID_CASE"][unique(data@Data["VALID_CASE"][duplicated(data@Data["VALID_CASE"], by=key(data@Data)), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE], by=key(data@Data))])
 			save(DUPLICATED_CASES, file="DUPLICATED_CASES.Rdata")
 		}
 
@@ -145,7 +154,7 @@ function(data,
 			SGPstateData[[state]][["Achievement"]][["Knots_Boundaries"]] <- createKnotsBoundaries(data@Data)
 			assign(paste(state, "Knots_Boundaries", sep="_"), SGPstateData[[state]][["Achievement"]][["Knots_Boundaries"]])
 			save(list=paste(state, "Knots_Boundaries", sep="_"), file=paste(state, "Knots_Boundaries.Rdata", sep="_"))
-			message(paste("\tNOTE: Knots and Boundaries do not exist for state provided.\n\tThey have been produced and are available using state=", state, " for subsequent analyses and saved to your working directory '", getwd(), "'.", sep=""))
+			messageSGP(paste0("\tNOTE: Knots and Boundaries do not exist for state provided.\n\tThey have been produced and are available using state=", state, " for subsequent analyses and saved to your working directory '", getwd(), "'."))
 		}
 
 		## Create FIRST_OBESRVATION, LAST_OBSERVATION if YEAR_WITHIN exists
@@ -175,10 +184,10 @@ function(data,
 		data <- as.data.table(data)
 		setnames(data, which(!is.na(variable.names$names.sgp)), variable.names$names.sgp[!is.na(variable.names$names.sgp)])
 		setkeyv(data, getKey(data))
-		if (is.null(fix.duplicates) && any(duplicated(data["VALID_CASE"]))) {
-			message(paste("\tWARNING: Data keyed by", paste(getKey(data), collapse=", "), "has duplicate cases. Subsequent joins/merges will be corrupted."))
-			message("\tNOTE: Duplicate cases are available in current workspace as 'DUPLICATED_CASES' and saved as 'DUPLICATED_CASES.Rdata'.")
-			assign("DUPLICATED_CASES", data["VALID_CASE"][unique(data["VALID_CASE"][duplicated(data["VALID_CASE"]), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE])])
+		if (is.null(fix.duplicates) && any(duplicated(data["VALID_CASE"], by=key(data)))) {
+			messageSGP(paste("\tWARNING: Data keyed by", paste(getKey(data), collapse=", "), "has duplicate cases. Subsequent joins/merges will be corrupted."))
+			messageSGP("\tNOTE: Duplicate cases are available in current workspace as 'DUPLICATED_CASES' and saved as 'DUPLICATED_CASES.Rdata'.")
+			assign("DUPLICATED_CASES", data["VALID_CASE"][unique(data["VALID_CASE"][duplicated(data["VALID_CASE"], by=key(data)), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE], by=key(data))])
 			save(DUPLICATED_CASES, file="DUPLICATED_CASES.Rdata")
 		}
 
@@ -189,7 +198,7 @@ function(data,
 			assign(paste(state, "Knots_Boundaries", sep="_"), SGPstateData[[state]][["Achievement"]][["Knots_Boundaries"]])
 			save(list=paste(state, "Knots_Boundaries", sep="_"), file=paste(state, "Knots_Boundaries.Rdata", sep="_"))
 			save(SGPstateData, file="SGPstateData.Rdata")
-			message(paste("\tNOTE: Knots and Boundaries do not exist for state provided.\n\tThey have been produced and are available using state=", state, " for subsequent analyses and saved to your working directory '", getwd(), "'.", sep=""))
+			messageSGP(paste0("\tNOTE: Knots and Boundaries do not exist for state provided.\n\tThey have been produced and are available using state=", state, " for subsequent analyses and saved to your working directory '", getwd(), "'."))
 		}
 
 		## Create FIRST_OBESRVATION, LAST_OBSERVATION if YEAR_WITHIN exists
@@ -225,7 +234,7 @@ function(data,
 			(!is.null(SGPstateData[[state]][["Achievement"]][["Cutscores"]]) | !is.null(SGPstateData[[state]][["Achievement"]][["Cutscore_Information"]]))) {
 		sgp_object@Data <- getAchievementLevel(sgp_object@Data, state=state)
 		setkeyv(sgp_object@Data, getKey(sgp_object))
-		message(paste("\tNOTE: Added variable ACHIEVEMENT_LEVEL to @Data using", state, "cutscores embedded in SGPstateData."))
+		messageSGP(paste("\tNOTE: Added variable ACHIEVEMENT_LEVEL to @Data using", state, "cutscores embedded in SGPstateData."))
 	}
 
 	if (create.additional.variables) {
@@ -244,27 +253,38 @@ function(data,
 		for (i in seq_along(tmp.enrollment_status.variables)) {
 			if (!tmp.enrollment_status.variables[i] %in% names(sgp_object@Data) & paste(tmp.enrollment_status.levels[i], "NUMBER", sep="_") %in% names(sgp_object@Data)) {
 				sgp_object@Data[[tmp.enrollment_status.variables[i]]] <-
-					factor(1, levels=0:1, labels=paste("Enrolled", capwords(tmp.enrollment_status.levels[i]), c(": No", ": Yes"), sep=""))
+					factor(1, levels=0:1, labels=paste0("Enrolled", capwords(tmp.enrollment_status.levels[i]), c(": No", ": Yes")))
 				sgp_object@Data[[tmp.enrollment_status.variables[i]]][sgp_object@Data[['VALID_CASE']]!="VALID_CASE"] <- NA
-				message(paste("\tNOTE: Added variable", tmp.enrollment_status.variables[i], "to @Data."))
+				messageSGP(paste("\tNOTE: Added variable", tmp.enrollment_status.variables[i], "to @Data."))
 			}
 		}
 
 	} ### end if (create.additional.variables)
 
-	if (!is.null(fix.duplicates) && !is.null(DUPLICATED_CASES)) {
+	if (!is.null(fix.duplicates)) {
 		if (identical(toupper(fix.duplicates), "KEEP.ALL")) {
-			if (all(unique(DUPLICATED_CASES$YEAR) %in% (tmp.last.year <- tail(sort(unique(sgp_object@Data$YEAR)), 1)))) {
-				sgp_object@Data <- createUniqueLongData(sgp_object@Data)
-				message("\tNOTE: Duplicate cases in current year made UNIQUE. Modified IDs include suffix '_DUPS_***' in @Data.")
+			if (is.SGP(data)) {
+				assign("DUPLICATED_CASES",
+					data@Data["VALID_CASE"][unique(data@Data["VALID_CASE"][duplicated(data@Data["VALID_CASE"], by=getKey(data@Data)), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE], by=getKey(data@Data))])
 			} else {
-				message("\tNOTE: Duplicate case modification is only available when duplicates reside in last year of data. Duplicate cases are NOT fixed.")
+				assign("DUPLICATED_CASES", data["VALID_CASE"][unique(data["VALID_CASE"][duplicated(data["VALID_CASE"], by=getKey(data)), c("VALID_CASE", "CONTENT_AREA", "YEAR", "ID"), with=FALSE], by=getKey(data))])
+			}
+			if (dim(DUPLICATED_CASES)[1]!=0) {
+				sgp_object@Data <- createUniqueLongData(sgp_object@Data)
+				messageSGP("\tNOTE: Duplicate cases in current year made UNIQUE. Modified IDs include suffix '_DUPS_***' in @Data.")
+
+				if (!all(unique(DUPLICATED_CASES$YEAR) %in% (tmp.last.year <- tail(sort(unique(sgp_object@Data$YEAR)), 1)))) {
+					setkey(DUPLICATED_CASES, VALID_CASE, CONTENT_AREA, YEAR, ID, GRADE)
+					if (any(duplicated(DUPLICATED_CASES[YEAR!=tmp.last.year], by=key(DUPLICATED_CASES)))) {
+						messageSGP("\tNOTE: Duplicate case modification is only available when duplicates reside in last year of data. Duplicate cases are NOT fixed.")
+					}
+				}
 			}
 		} ### End KEEP.ALL
 	}
 
 	##  Print finish time
-	message(paste("Finished prepareSGP", date(), "in", convertTime(timetaken(started.at)), "\n"))
+	messageSGP(paste("Finished prepareSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
 
 	return(sgp_object)
 } ## END prepareSGP function
