@@ -14,12 +14,13 @@
 	parallel.config=NULL) {
 
 	started.at <- proc.time()
-	messageSGP(paste("\nStarted summarizeSGP", date()), "\n")
+	messageSGP(paste("\nStarted summarizeSGP", prettyDate()), "\n")
 	messageSGP(match.call())
 
 	### Set variables to NULL to prevent R CMD check warnings
 	SIM_NUM <- tmp.simulation.dt <- variable <- WEIGHT <- ENROLLMENT_STATUS <- names.type <- names.sgp <- names.output <- BY_GROWTH_ONLY <- VALID_CASE <- YEAR_WITHIN <- NULL
 	tmp.simulation.dt <- variable <- WEIGHT <- ENROLLMENT_STATUS <- names.type <- names.sgp <- names.output <- BY_GROWTH_ONLY <- VALID_CASE <- YEAR_WITHIN <- NULL
+	CONTENT_AREA <- YEAR <- BASELINE <- NULL
 
 
 	### Create state (if NULL) from sgp_object (if possible)
@@ -45,11 +46,11 @@
 			tmp.file.name <- paste(tmp.state.name, "SGP_Summary", tmp.year, sep="_")
 			assign(tmp.file.name, sgp_object@Summary)
 			if (!"Data" %in% list.files()) dir.create("Data", showWarnings=FALSE)
-			message(paste("\tNOTE: Saving @Summary slot to", paste("Data/", tmp.file.name, ".Rdata and then deleting @Summary slot.", sep="")))
+			messageSGP(paste("\tNOTE: Saving @Summary slot to", paste0("Data/", tmp.file.name, ".Rdata and then deleting @Summary slot.")))
 			save(list=tmp.file.name, file=file.path("Data", paste(tmp.file.name, "Rdata", sep=".")))
 			sgp_object@Summary <- NULL
 		} else {
-			message("\tNOTE: Deleting @Summary slot")
+			messageSGP("\tNOTE: Deleting @Summary slot")
 			sgp_object@Summary <- NULL
 		}
 	}
@@ -101,10 +102,10 @@
 			return(NULL)
 		}
 		if (!is.null(my.group) & add.missing) {
-			return(c("", unlist(lapply(my.group, function(x) paste(", ", x, sep="")))))
+			return(c("", unlist(lapply(my.group, function(x) paste0(", ", x)))))
 		}
 		if (!is.null(my.group) & !add.missing) {
-			return(unlist(lapply(my.group, function(x) paste(", ", x, sep=""))))
+			return(unlist(lapply(my.group, function(x) paste0(", ", x))))
 		}
 	}
 
@@ -114,11 +115,11 @@
 			if (length(grep("BASELINE", i) > 0)) tmp.baseline <- "BASELINE" else tmp.baseline <- "COHORT"
 			if ("YEAR_WITHIN" %in% names(sgp_object@SGP[["Simulated_SGPs"]][[i]])) columns.to.omit <- -c(1,2) else columns.to.omit <- -1
 			tmp.list[[i]] <- data.table(
-				ID=rep(sgp_object@SGP[["Simulated_SGPs"]][[i]][["ID"]], each=length(grep("SGP_SIM", names(sgp_object@SGP[["Simulated_SGPs"]][[i]])))),
-				SGP_SIM=as.integer(as.matrix(t(sgp_object@SGP[["Simulated_SGPs"]][[i]][,columns.to.omit, with=FALSE]))))[,
-				"CONTENT_AREA":=unlist(strsplit(i, "[.]"))[1]][,
-				"YEAR":=unlist(strsplit(i, "[.]"))[2]][,
-				"BASELINE":=tmp.baseline]
+				ID=sgp_object@SGP[["Simulated_SGPs"]][[i]][["ID"]],
+				SGP_SIM=c(as.matrix(sgp_object@SGP[["Simulated_SGPs"]][[i]][,columns.to.omit, with=FALSE])))[,
+					CONTENT_AREA:=unlist(strsplit(i, "[.]"))[1]][,
+					YEAR:=unlist(strsplit(i, "[.]"))[2]][,
+					BASELINE:=tmp.baseline]
 			if ("YEAR_WITHIN" %in% names(sgp_object@SGP[["Simulated_SGPs"]][[i]])) {
 				tmp.list[[i]][,YEAR_WITHIN:=rep(sgp_object@SGP[["Simulated_SGPs"]][[i]][["YEAR_WITHIN"]], each=length(grep("SGP_SIM", names(sgp_object@SGP[["Simulated_SGPs"]][[i]]))))]
 			}
@@ -131,7 +132,7 @@
 		if (config.type=="sgp.summaries") {
 			if (!is.null(SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]])) {
 				tmp.achievement.levels <- SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]][
-+                         grep("Achievement_Levels", names(SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]]))]
+                         grep("Achievement_Levels", names(SGP::SGPstateData[[state]][["Assessment_Program_Information"]][["Assessment_Transition"]]))]
 				all.achievement.levels <- unlist(lapply(tmp.achievement.levels, function(x) x[['Labels']]), use.names=FALSE)
 				proficient.achievement.levels <- all.achievement.levels[unlist(lapply(tmp.achievement.levels, function(x) x[['Proficient']]=="Proficient"))]
 			} else {
@@ -144,7 +145,7 @@
 				if (length(character.vector)==0) {
 					return(NULL)
 				} else {
-					paste("list(c(", paste("'", paste(character.vector, collapse="', '"), "'", sep=""), "))", sep="")
+					paste0("c(", paste0("'", paste(character.vector, collapse="', '"), "'"), ")")
 				}
 			}
 
@@ -152,8 +153,8 @@
 				MEAN_SGP="mean_na(SGP, WEIGHT)",
 				MEDIAN_SGP="median_na(SGP, WEIGHT)",
 				MEDIAN_SGP_COUNT="num_non_missing(SGP)",
-				PERCENT_AT_ABOVE_PROFICIENT=paste("percent_in_category(ACHIEVEMENT_LEVEL, ",
-					get.expression(proficient.achievement.levels), ", ", get.expression(all.achievement.levels), ")",sep=""),
+				PERCENT_AT_ABOVE_PROFICIENT=paste0("percent_in_category(ACHIEVEMENT_LEVEL, ",
+					get.expression(proficient.achievement.levels), ", ", get.expression(all.achievement.levels), ")"),
 				PERCENT_AT_ABOVE_PROFICIENT_COUNT="num_non_missing(ACHIEVEMENT_LEVEL)",
 				MEAN_SGP_STANDARD_ERROR="sgp_standard_error(SGP)",
 				MEDIAN_SGP_STANDARD_ERROR="sgp_standard_error(SGP, 1.253)")
@@ -171,8 +172,8 @@
 				if ("ACHIEVEMENT_LEVEL_PRIOR" %in% sgp.data.names) {
 					tmp.sgp.summaries <- c(
 						tmp.sgp.summaries,
-						PERCENT_AT_ABOVE_PROFICIENT_PRIOR=paste("percent_in_category(ACHIEVEMENT_LEVEL_PRIOR, ",
-							get.expression(proficient.achievement.levels), ", ", get.expression(all.achievement.levels), ")",sep=""),
+						PERCENT_AT_ABOVE_PROFICIENT_PRIOR=paste0("percent_in_category(ACHIEVEMENT_LEVEL_PRIOR, ",
+							get.expression(proficient.achievement.levels), ", ", get.expression(all.achievement.levels), ")"),
 						PERCENT_AT_ABOVE_PROFICIENT_PRIOR_COUNT="num_non_missing(ACHIEVEMENT_LEVEL_PRIOR)"
 					)
 				}
@@ -208,9 +209,9 @@
 				if (!is.null(my.sgp.target)) {
 					tmp.sgp.summaries <- c(
 						tmp.sgp.summaries,
-						M1=paste("median_na(", my.sgp.target, ", WEIGHT)", sep=""),
-						M2=paste("num_non_missing(", my.sgp.target, ")", sep=""),
-						PERCENT_CATCHING_UP_KEEPING_UP="percent_in_category(CATCH_UP_KEEP_UP_STATUS, list(c('Catch Up: Yes', 'Keep Up: Yes')), list(c('Catch Up: Yes', 'Catch Up: No', 'Keep Up: Yes', 'Keep Up: No')))"
+						M1=paste0("median_na(", my.sgp.target, ", WEIGHT)"),
+						M2=paste0("num_non_missing(", my.sgp.target, ")"),
+						PERCENT_CATCHING_UP_KEEPING_UP="percent_in_category(CATCH_UP_KEEP_UP_STATUS, c('Catch Up: Yes', 'Keep Up: Yes'), c('Catch Up: Yes', 'Catch Up: No', 'Keep Up: Yes', 'Keep Up: No'))"
 					)
 					names(tmp.sgp.summaries)[sapply(c("M1", "M2"), function(x) which(names(tmp.sgp.summaries)==x))] <-
 						c(paste("MEDIAN", my.sgp.target, sep="_"), paste("MEDIAN", my.sgp.target, "COUNT", sep="_"))
@@ -219,9 +220,9 @@
 				if (!is.null(my.sgp.target.baseline)) {
 					tmp.sgp.summaries <- c(
 						tmp.sgp.summaries,
-						M1=paste("median_na(", my.sgp.target.baseline, ", WEIGHT)", sep=""),
-						M2=paste("num_non_missing(", my.sgp.target.baseline, ")", sep=""),
-						PERCENT_CATCHING_UP_KEEPING_UP_BASELINE="percent_in_category(CATCH_UP_KEEP_UP_STATUS_BASELINE, list(c('Catch Up: Yes', 'Keep Up: Yes')), list(c('Catch Up: Yes', 'Catch Up: No', 'Keep Up: Yes', 'Keep Up: No')))"
+						M1=paste0("median_na(", my.sgp.target.baseline, ", WEIGHT)"),
+						M2=paste0("num_non_missing(", my.sgp.target.baseline, ")"),
+						PERCENT_CATCHING_UP_KEEPING_UP_BASELINE="percent_in_category(CATCH_UP_KEEP_UP_STATUS_BASELINE, c('Catch Up: Yes', 'Keep Up: Yes'), c('Catch Up: Yes', 'Catch Up: No', 'Keep Up: Yes', 'Keep Up: No'))"
 					)
 					names(tmp.sgp.summaries)[sapply(c("M1", "M2"), function(x) which(names(tmp.sgp.summaries)==x))] <-
 						c(paste("MEDIAN", my.sgp.target.baseline, sep="_"), paste("MEDIAN", my.sgp.target.baseline, "COUNT", sep="_"))
@@ -231,9 +232,9 @@
 				if (!is.null(my.sgp.target.musu)) {
 					tmp.sgp.summaries <- c(
 						tmp.sgp.summaries,
-						M1=paste("median_na(", my.sgp.target.musu, ", WEIGHT)", sep=""),
-						M2=paste("num_non_missing(", my.sgp.target.musu, ")", sep=""),
-						PERCENT_MOVING_UP_STAYING_UP="percent_in_category(MOVE_UP_STAY_UP_STATUS, list(c('Move Up: Yes', 'Stay Up: Yes')), list(c('Move Up: Yes', 'Move Up: No', 'Stay Up: Yes', 'Stay Up: No')))"
+						M1=paste0("median_na(", my.sgp.target.musu, ", WEIGHT)"),
+						M2=paste0("num_non_missing(", my.sgp.target.musu, ")"),
+						PERCENT_MOVING_UP_STAYING_UP="percent_in_category(MOVE_UP_STAY_UP_STATUS, c('Move Up: Yes', 'Stay Up: Yes'), c('Move Up: Yes', 'Move Up: No', 'Stay Up: Yes', 'Stay Up: No'))"
 					)
 					names(tmp.sgp.summaries)[sapply(c("M1", "M2"), function(x) which(names(tmp.sgp.summaries)==x))] <-
 						c(paste("MEDIAN", my.sgp.target.musu, sep="_"), paste("MEDIAN", my.sgp.target.musu, "COUNT", sep="_"))
@@ -242,9 +243,9 @@
 				if (!is.null(my.sgp.target.musu.baseline)) {
 					tmp.sgp.summaries <- c(
 						tmp.sgp.summaries,
-						M1=paste("median_na(", my.sgp.target.musu.baseline, ", WEIGHT)", sep=""),
-						M2=paste("num_non_missing(", my.sgp.target.musu.baseline, ")", sep=""),
-						PERCENT_MOVING_UP_STAYING_UP_BASELINE="percent_in_category(MOVE_UP_STAY_UP_STATUS_BASELINE, list(c('Move Up: Yes', 'Stay Up: Yes')), list(c('Move Up: Yes', 'Move Up: No', 'Stay Up: Yes', 'Stay Up: No')))"
+						M1=paste0("median_na(", my.sgp.target.musu.baseline, ", WEIGHT)"),
+						M2=paste0("num_non_missing(", my.sgp.target.musu.baseline, ")"),
+						PERCENT_MOVING_UP_STAYING_UP_BASELINE="percent_in_category(MOVE_UP_STAY_UP_STATUS_BASELINE, c('Move Up: Yes', 'Stay Up: Yes'), c('Move Up: Yes', 'Move Up: No', 'Stay Up: Yes', 'Stay Up: No'))"
 					)
 					names(tmp.sgp.summaries)[sapply(c("M1", "M2"), function(x) which(names(tmp.sgp.summaries)==x))] <-
 						c(paste("MEDIAN", my.sgp.target.musu.baseline, sep="_"), paste("MEDIAN", my.sgp.target.musu.baseline, "COUNT", sep="_"))
@@ -344,14 +345,14 @@
 		tmp.summary <- list()
 
 		### Create summary tables
-		sgp.groups <- do.call(paste, c(expand.grid(i,
+		sgp.groups <- do.call(paste0, expand.grid(i,
 			group.format(summary.groups[["institution_type"]]),
 			group.format(summary.groups[["content"]]),
 			group.format(summary.groups[["time"]]),
 			group.format(summary.groups[["institution_level"]]),
 			group.format(summary.groups[["demographic"]]),
 			group.format(summary.groups[["institution_inclusion"]][[i]]),
-			group.format(summary.groups[["growth_only_summary"]][[i]])), sep=""))
+			group.format(summary.groups[["growth_only_summary"]][[i]])))
 
 		if (!produce.all.summary.tables) {
 			sgp.groups <- intersect(sgp.groups, selected.summary.tables)
@@ -359,14 +360,14 @@
 		}
 
 		if (!is.null(confidence.interval.groups[["GROUPS"]]) & i %in% confidence.interval.groups[["GROUPS"]][["institution"]]) {
-			ci.groups <- do.call(paste, c(expand.grid(i,
+			ci.groups <- do.call(paste0, expand.grid(i,
 				group.format(confidence.interval.groups[["GROUPS"]][["institution_type"]]),
 				group.format(confidence.interval.groups[["GROUPS"]][["content"]]),
 				group.format(confidence.interval.groups[["GROUPS"]][["time"]]),
 				group.format(confidence.interval.groups[["GROUPS"]][["institution_level"]]),
 				group.format(confidence.interval.groups[["GROUPS"]][["demographic"]]),
 				group.format(confidence.interval.groups[["GROUPS"]][["institution_inclusion"]][[i]]),
-				group.format(confidence.interval.groups[["GROUPS"]][["growth_only_summary"]][[i]])), sep=""))
+				group.format(confidence.interval.groups[["GROUPS"]][["growth_only_summary"]][[i]])))
 
 			if (!produce.all.summary.tables) ci.groups <- intersect(ci.groups, selected.summary.tables)
 		}
@@ -381,12 +382,12 @@
 				tmp.summary[[s]] <- sgpSummary(summary.iter[[s]][1], eval(parse(text=summary.iter[[s]][2])),
 					tmp.simulation.dt, state, sgp.summaries, confidence.interval.groups, my.sgp, sgp_key, variables.for.summaries, sim.info)
 			}
-			parallel.config <- list(BACKEND="NONE"); par.start <- list(par.type="NONE")
+			par.start <- list(par.type="NONE")
 		}
 
 		j <- k <- NULL ## To prevent R CMD check warnings
 
-		if (parallel.config[["BACKEND"]] == "FOREACH") {
+		if (identical(parallel.config[["BACKEND"]], "FOREACH")) {
 			if (!is.null(confidence.interval.groups[["GROUPS"]]) & i %in% confidence.interval.groups[["GROUPS"]][["institution"]]) {
 				k.iter <- iter(sgp.groups %in% ci.groups)
 			} else	k.iter <- iter(rep(FALSE, length(sgp.groups)))
@@ -399,17 +400,17 @@
 		} else { # END FOREACH flavor
 
 		### SNOW and MULTICORE
-		if (par.start$par.type=="SNOW") {
+		if (identical(par.start[['par.type']], "SNOW")) {
 			tmp.summary <- parLapply(par.start$internal.cl, summary.iter,
 				function(iter) sgpSummary(iter[1], eval(parse(text=iter[2])), tmp.simulation.dt, state, sgp.summaries, confidence.interval.groups, my.sgp, sgp_key, variables.for.summaries, sim.info))
 		} # END 'SNOW' Flavor
-		if (par.start$par.type=="MULTICORE") {
+		if (identical(par.start[['par.type']], "MULTICORE")) {
 			tmp.summary <- mclapply(summary.iter,
 				function(iter) sgpSummary(iter[1], eval(parse(text=iter[2])), tmp.simulation.dt, state, sgp.summaries, confidence.interval.groups, my.sgp, sgp_key, variables.for.summaries, sim.info), mc.cores=par.start$workers, mc.preschedule=FALSE)
 		} # END 'MULTICORE' Flavor
 		} # END else not FOREACH
 
-		names(tmp.summary) <- gsub(", ", "__", sgp.groups)
+		setattr(tmp.summary, 'names', gsub(', ', '__', sgp.groups))
 		return(tmp.summary)
 	} ### END summarizeSGP_INTERNAL
 
@@ -421,24 +422,24 @@
 	###################################################################################
 
 	if (is.null(content_areas)) {
-		content_areas <- unique(sgp_object@Data["VALID_CASE"]$CONTENT_AREA)
+		content_areas <- unique(sgp_object@Data["VALID_CASE"], by='CONTENT_AREA')[['CONTENT_AREA']]
 	}
 
 	if (is.null(SGP::SGPstateData[[state]][["SGP_Configuration"]][["state.multiple.year.summary"]])) {
-		state.multiple.year.summary <- 3
+		state.multiple.year.summary <- 5
 	} else {
 		state.multiple.year.summary <- SGP::SGPstateData[[state]][["SGP_Configuration"]][["state.multiple.year.summary"]]
 	}
 	tmp.years <- list()
 	if (is.null(years)) {
 		for (i in content_areas) {
-			tmp.years[[i]] <- tail(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)]$YEAR)), state.multiple.year.summary)
+			tmp.years[[i]] <- tail(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)], by='YEAR')[['YEAR']]), state.multiple.year.summary)
 		}
 	} else {
 		if (!is.list(years)) {
 			for (i in content_areas) {
-				tmp.years[[i]] <- tail(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)]$YEAR))[
-					seq(which(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)]$YEAR))==tail(sort(years), 1)))], state.multiple.year.summary)
+				tmp.years[[i]] <- tail(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)], by='YEAR')[['YEAR']])[
+					seq(which(sort(unique(sgp_object@Data[SJ("VALID_CASE", i)], by='YEAR')[['YEAR']])==tail(sort(years), 1)))], state.multiple.year.summary)
 			}
 		} else {
 			if (!all(content_areas %in% names(years))) {
@@ -495,20 +496,20 @@
 			}
 
 			if (length(grep("SCHOOL", k)) > 0) {
-				selected.summary.tables[[k]] <- do.call(paste,
-					c(expand.grid(k,
+				selected.summary.tables[[k]] <- do.call(paste0,
+					expand.grid(k,
 						group.format("EMH_LEVEL"),
 						group.format("CONTENT_AREA"),
 						group.format("YEAR"),
 						group.format("GRADE"),
-						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)), sep=""))
+						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)))
 			} else {
-				selected.summary.tables[[k]] <- do.call(paste,
-					c(expand.grid(k,
+				selected.summary.tables[[k]] <- do.call(paste0,
+					expand.grid(k,
 						group.format("CONTENT_AREA"),
 						group.format("YEAR"),
 						group.format("GRADE"),
-						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)), sep=""))
+						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)))
 			}
 		} else {
 			if (is.null(summary.groups[["institution_inclusion"]][[k]])) {
@@ -520,22 +521,22 @@
 			}
 
 			if (length(grep("SCHOOL", k)) > 0 & !is.null(summary.groups[["institution_inclusion"]][[k]])) {
-				selected.summary.tables[[k]] <- do.call(paste,
-					c(expand.grid(k,
+				selected.summary.tables[[k]] <- do.call(paste0,
+					expand.grid(k,
 						group.format("EMH_LEVEL"),
 						group.format("CONTENT_AREA"),
 						group.format("YEAR"),
 						group.format("GRADE"),
 						group.format(selected.demographic.subgroups),
-						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)), sep=""))
+						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)))
 			} else {
-				selected.summary.tables[[k]] <- do.call(paste,
-					c(expand.grid(k,
+				selected.summary.tables[[k]] <- do.call(paste0,
+					expand.grid(k,
 						group.format("CONTENT_AREA"),
 						group.format("YEAR"),
 						group.format("GRADE"),
 						group.format(selected.demographic.subgroups),
-						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)), sep=""))
+						group.format(ENROLLMENT_STATUS_ARGUMENT, ADD_MISSING_ARGUMENT)))
 			}
 		}
 	} ### End for k
@@ -558,13 +559,13 @@
 
 	if (any(!sapply(summary.groups[["growth_only_summary"]], is.null))) {
 		tmp.dt <- sgp_object@Data[data.table("VALID_CASE", content_areas.by.years), nomatch=0][,
-			variables.for.summaries, with=FALSE][, highest.level.summary.grouping:=state, with=FALSE]
-		dbWriteTable(sgp_data_for_summary, name = "summary_data", overwrite = TRUE, row.names=0, value = tmp.dt[,
+			variables.for.summaries, with=FALSE][, (highest.level.summary.grouping):=state]
+		dbWriteTable(sgp_data_for_summary, name = "summary_data", overwrite = TRUE, row.names=FALSE, value = tmp.dt[,
 			BY_GROWTH_ONLY := factor(is.na(tmp.dt[[my.sgp[1]]]), levels=c(FALSE, TRUE), labels=c("Students without SGP", "Students with SGP"))])
 	} else {
-		dbWriteTable(sgp_data_for_summary, name = "summary_data", overwrite = TRUE, row.names=0,
+		dbWriteTable(sgp_data_for_summary, name = "summary_data", overwrite = TRUE, row.names=FALSE,
 			value = sgp_object@Data[data.table("VALID_CASE", content_areas.by.years), nomatch=0][,
-				variables.for.summaries, with=FALSE][, highest.level.summary.grouping:=state, with=FALSE])
+				variables.for.summaries, with=FALSE][, (highest.level.summary.grouping):=state])
 	}
 
 	if (!is.null(confidence.interval.groups) & "CSEM" %in% confidence.interval.groups[['TYPE']]) {
@@ -574,7 +575,7 @@
 		if ((!identical(.Platform$OS.type, "unix") & !is.null(parallel.config)) | !is.null(parallel.config[["SNOW_TEST"]])) {
 			# Write tmp.simulation.dt to disk for SNOW backends in Windows (& SNOT_TEST) Only
 			tmp.simulation.dt <- "sqlite"
-			dbWriteTable(sgp_data_for_summary, name = "sim_data", overwrite = TRUE, row.names=0,
+			dbWriteTable(sgp_data_for_summary, name = "sim_data", overwrite = TRUE, row.names=FALSE,
 				value = combineSims(sgp_object)[, SIM_NUM := 1:sim.info[['n.simulated.sgps']]])
 		} else {
 			tmp.simulation.dt <- combineSims(sgp_object)
@@ -615,7 +616,7 @@
 
 				### Create LONGer data and run summarizeSGP_INTERNAL
 				tmp.dt.long <- sgp_object@Data[data.table("VALID_CASE", content_areas.by.years), nomatch=0][,
-					variables.for.summaries, with=FALSE][, highest.level.summary.grouping:=state, with=FALSE]
+					variables.for.summaries, with=FALSE][, (highest.level.summary.grouping):=state]
 				tmp.dt.long[, BY_GROWTH_ONLY := factor(is.na(tmp.dt.long[[my.sgp[1]]]), levels=c(FALSE, TRUE), labels=c("Students without SGP", "Students with SGP"))]
 				tmp.dt.long <- tmp.dt.long[data.table(sgp_object@Data_Supplementary[[j-1]][,VALID_CASE:="VALID_CASE"], key=sgp_key), nomatch=0]
 
@@ -624,7 +625,7 @@
 				}
 
 				dbWriteTable(dbConnect(SQLite(), dbname = "Data/tmp_data/TMP_Summary_Data.sqlite"),
-					name = "summary_data", overwrite = TRUE, row.names=0, value = tmp.dt.long)
+					name = "summary_data", overwrite = TRUE, row.names=FALSE, value = tmp.dt.long)
 
 				sgp_object@Summary[[i]] <- c(sgp_object@Summary[[i]], summarizeSGP_INTERNAL(tmp.inst))
 			}
@@ -639,7 +640,7 @@
 		setkeyv(sgp_object@Data, getKey(sgp_object))
 	}
 
-	messageSGP(paste("Finished summarizeSGP", date(), "in", convertTime(timetaken(started.at)), "\n"))
+	messageSGP(paste("Finished summarizeSGP", prettyDate(), "in", convertTime(timetaken(started.at)), "\n"))
 
 	return(sgp_object)
 } ## END summarizeSGP Function
